<?php

/*
 * This file is part of the API Platform project.
 *
 * (c) Kévin Dunglas <dunglas@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace ApiPlatform\Core\Api;

use ApiPlatform\Core\Exception\ExceptionInterface;
use ApiPlatform\Core\Exception\ResourceClassNotSupportedException;

/**
 * Retrieves items from a persistence layer.
 *
 * @author Kévin Dunglas <dunglas@gmail.com>
 */
interface ItemDataProviderInterface
{
    /**
     * Retrieves an item.
     *
     * @param string      $resourceClass
     * @param string|null $operationName
     * @param int|string  $id
     * @param bool        $fetchData
     *
     * @throws ResourceClassNotSupportedException
     * @throws ExceptionInterface
     *
     * @return object|null
     */
    public function getItem(string $resourceClass, $id, string $operationName = null, bool $fetchData = false);
}
